@@ -31,8 +31,14 @@ class Storage(driver.Base):
         self._jss = JssClient(self._access_key, self._secret_key, self._domain, None)
         
     def _init_path(self, path=None):
-        if  path:
-            return path.replace("/", ".")
+        if path:
+            if path.startwith('/'):
+                path = path[1]
+            if path.endswith('/'):
+                path = path[:-1]
+        return path
+#        if  path:
+#            return path.replace("/", ".")
        
     def content_redirect_url(self, path):
         logger.info("content_redirect_url path:%s" % path)
@@ -111,24 +117,12 @@ class Storage(driver.Base):
             
             for file in files:
                 logger.info("list_directory key:%s" % file["Key"])
-                yield file["Key"].replace(".", "/")
+#                yield file["Key"].replace(".", "/")
+                yield file["Key"]
         except Exception as e:
             logger.error("list_directory error:%s" % e)
             raise exceptions.FileNotFoundError("File not found %s" % path)
         
-#    def stream_write(self, path, fp):
-#         logger.info("stream_write path:%s " % path)
-#         path1 = self._init_path(path)
-#
-#         try:
-#             object_instance = self._jss.bucket(self._bucket).object(path1)
-#             l = fp.read(self.buffer_size)
-#             logger.info("stream_write,begin to write the content to jss ")
-#             while len(l) > 0:
-#                 object_instance.upload_flow(None, l, True)
-#                 l = fp.read(self.buffer_size)
-#         except IOError as e :
-#            logger.error("stream_write error:%s" % e)
          
     def stream_write(self, path, fp):
         logger.info("stream_write path:%s" % path)
